aboutsummaryrefslogtreecommitdiffstats
path: root/test/test_stdin.py
diff options
context:
space:
mode:
Diffstat (limited to 'test/test_stdin.py')
-rwxr-xr-xtest/test_stdin.py10
1 files changed, 5 insertions, 5 deletions
diff --git a/test/test_stdin.py b/test/test_stdin.py
index 11b1ca21..2161a95a 100755
--- a/test/test_stdin.py
+++ b/test/test_stdin.py
@@ -1,6 +1,6 @@
#!/usr/bin/env python3
"""Test reading from stdin with serdi."""
import argparse
import sys
@@ -10,15 +10,15 @@ import tempfile
parser = argparse.ArgumentParser(description=__doc__)
-parser.add_argument("--serdi", default="./serdi", help="path to serdi")
+parser.add_argument("--tool", default="tools/serd-pipe", help="executable")
parser.add_argument("--wrapper", default="", help="executable wrapper")
args = parser.parse_args(sys.argv[1:])
command = shlex.split(args.wrapper) + [
- args.serdi,
- "-I",
+ args.tool,
+ "-B",
"http://example.org",
- "-i",
+ "-I",
"ntriples",
"-",
]
@@ -1,6 +1,6 @@
#!/usr/bin/env python3
-"""Test reading from stdin with serdi."""
+"""Test reading from stdin with serd-pipe."""
import argparse
import sys